@@ -147,9 +147,7 @@ class PythonExpression:
         names.difference_update(globals())
         if not all_variables_allowed and not names <= variables:
             raise ParserVariableMissing(
-                'the following variable names are unknown: {}'.format(
-                    ', '.join(names - variables))
-            )
+                'the following variable names are unknown: {}'.format(', '.join(names - variables)))
 
         self.variables = names
         self.constants = constants
@@ -224,6 +222,13 @@ def sliceobj(expression: Union[int, str, slice], variables: Optional[dict] = Non
         if not range:
             return slice(k, k + 1) if k + 1 else slice(k, None, None)
         return slice(0, k)
+    for k, item in enumerate(sliced):
+        if item is None or isinstance(item, int):
+            continue
+        if isbuffer(item) and len(item) in (1, 2, 4, 8, 16):
+            sliced[k] = int.from_bytes(item, 'little')
+            continue
+        raise TypeError(F'The value {item!r} of type {type(item).__name__} cannot be used as a slice index.')
     return slice(*sliced)
 
 
@@ -542,7 +547,7 @@ class DelayedArgument(LazyEvaluation):
         as a `refinery.lib.argformats.sliceobj`. The result contains the corresponding slice
         of the input data.
         """
-        return lambda d: memoryview(d)[sliceobj(region, d.meta)]
+        return lambda d: d[sliceobj(region, d.meta)]
 
     @handler.register('x', 'cut', final=True)
     def cut(self, region: str) -> bytes:
@@ -736,19 +741,20 @@ class DelayedArgument(LazyEvaluation):
         def finalize(data: Optional[Chunk] = None):
             @lru_cache(maxsize=512, typed=False)
             def accumulate(A):
-                return update(args, A=A)
-            args = metavars(data)
-            A = seed and seed(args) or 0
+                return update(meta, A=A)
+            meta = metavars(data)
+            A = seed and seed(meta) or 0
             while True:
                 yield A
                 A = accumulate(A)
                 if mask:
                     A &= mask
-
         try:
-            return finalize()
+            update(A=seed())
         except ParserVariableMissing:
             return finalize
+        else:
+            return finalize()
 
     @handler.register('be')
     def be(self, arg: Union[int, ByteString]) -> int:
