@@ -3,8 +3,11 @@
 """
 Library of regular expression patterns.
 """
-import re
 import enum
+import functools
+import re
+
+from typing import Optional
 
 from .tlds import tlds
 
@@ -15,19 +18,41 @@ class pattern:
     allowing combination of several patterns into one via overloaded
     operators.
     """
+    str_pattern: str
+    bin_pattern: Optional[bytes]
+    bin_compiled: re.Pattern
+    str_compiled: re.Pattern
 
-    def __init__(self, pattern):
-        self.pattern = pattern
-        self.compiled = re.compile(B'(%s)' % self)
+    def __init__(self, pattern: str):
+        self.str_pattern = pattern
+        self.bin_pattern = None
+        self.bin_compiled = re.compile(B'(%s)' % self)
+        self.str_compiled = re.compile(self.str_pattern)
 
     def __bytes__(self):
-        return str(self).encode('ascii')
+        bin_pattern = self.bin_pattern
+        if bin_pattern is None:
+            self.bin_pattern = bin_pattern = self.str_pattern.encode('ascii')
+        return bin_pattern
 
     def __str__(self):
-        return self.pattern
+        return self.str_pattern
 
     def __getattr__(self, verb):
-        return getattr(self.compiled, verb)
+        bin_attr = getattr(self.bin_compiled, verb)
+        if not callable(bin_attr):
+            return bin_attr
+        str_attr = getattr(self.str_compiled, verb)
+
+        def wrapper(*args, **kwargs):
+            for argument in args:
+                if isinstance(argument, str):
+                    return str_attr(*args, **kwargs)
+            else:
+                return bin_attr(*args, **kwargs)
+
+        functools.update_wrapper(wrapper, bin_attr)
+        return wrapper
 
 
 class alphabet(pattern):
@@ -154,7 +179,7 @@ _pattern_defanged_socket = '(?:{ip}|{d})(?::\\d{{2,5}})'.format(ip=_pattern_defa
 _pattern_serrated_hostname = _pattern_serrated_socket + '?'
 _pattern_defanged_hostname = _pattern_defanged_socket + '?'
 
-_pattern_integer = '[-+]?(?:0[bB][01]+|0[xX][0-9a-fA-F]+|0[1-7][0-7]*|[1-9][0-9]*|0)(?=[iI]\\d{1,2}|[LlHh]|[^a-zA-Z0-9]|$)'
+_pattern_integer = '[-+]?(?:0[bB][01]+|0[xX][0-9a-fA-F]+|0[1-7][0-7]*|[1-9][0-9]*|0)(?=[uU]?[iI]\\d{1,2}|[LlHh]|[^a-zA-Z0-9]|$)'
 _pattern_float = R'[-+]?[0-9]*\.?[0-9]+(?:[eE][-+]?[0-9]+)?'
 _pattern_cmdstr = R'''(?:"(?:""|[^"])*"|'(?:''|[^'])*')'''
 _pattern_ps1str = R'''(?:@"\s*?[\r\n].*?[\r\n]"@|@'\s*?[\r\n].*?[\r\n]'@|"(?:`.|""|[^"])*"|'(?:''|[^'])*')'''
@@ -207,7 +232,7 @@ def make_hexline_pattern(blocksize: int) -> str:
         h=tokenize(
             RF'(?:0[xX])?[0-9a-fA-F]{{{2 * blocksize}}}h?',
             sep=R'[- \t\/:;,\\]{1,3}'
-        ).pattern,
+        ).str_pattern,
         s=R'[-\w:;,#\.\$\?!\/\\=\(\)\[\]\{\}]'
     )
 
@@ -244,7 +269,7 @@ class formats(PatternEnum):
     "Windows command line escaped string literal"
     ps1str = pattern(_pattern_ps1str)
     "PowerShell escaped string literal"
-    printable = alphabet(R'[ -~]')
+    printable = alphabet(R'[\s!-~]')
     "Any sequence of printable characters"
     url_encoded_coarse = pattern(_pattern_urlenc_coarse)
     "Any sequence of url-encoded characters, coarse variant"
