@@ -9,6 +9,7 @@ from . import arg, HexViewer
 from ...lib.meta import metavars, CustomStringRepresentation, SizeInt
 from ...lib.types import INF
 from ...lib.tools import isbuffer, lookahead
+from ...lib.patterns import formats
 
 
 class peek(HexViewer):
@@ -51,7 +52,7 @@ class peek(HexViewer):
     def process(self, data):
         for line in self._peeklines(data):
             print(line, file=sys.stderr)
-        if not sys.stdout.isatty():
+        if not self.isatty:
             self.log_info('forwarding input to next unit')
             yield data
 
@@ -69,10 +70,9 @@ class peek(HexViewer):
             elif isbuffer(value):
                 try:
                     decoded: str = value.decode(self.codec)
-                    assert decoded.isprintable()
                 except UnicodeDecodeError:
                     decoded = None
-                except AssertionError:
+                if not formats.printable.match(decoded):
                     decoded = None
                 value = decoded or F'h:{value.hex()}'
             elif isinstance(value, int):
@@ -95,14 +95,18 @@ class peek(HexViewer):
                 result.append(decoded[k:k + width])
             return result
         try:
+            printable = string.printable + string.whitespace
             self.log_info(F'trying to decode as {codec}.')
             decoded = codecs.decode(data, codec, errors='strict')
-            count = sum(x in string.printable for x in decoded)
+            count = sum(x in printable for x in decoded)
             ratio = count / len(data)
+        except UnicodeDecodeError as DE:
+            self.log_info('decoding failed:', DE.reason)
+            return None
         except ValueError as V:
             self.log_info('decoding failed:', V)
             return None
-        if ratio < 0.8 or any(x in decoded for x in '\b\v'):
+        if ratio < 0.8:
             self.log_info(F'data contains {ratio * 100:.2f}% printable characters, this is too low.')
             return None
         for paragraph in decoded.splitlines(False):
@@ -132,6 +136,7 @@ class peek(HexViewer):
         lines = None
         index = None
         final = True
+        empty = True
 
         if data.temp:
             final, index = data.temp
@@ -158,6 +163,8 @@ class peek(HexViewer):
                     if lines:
                         codec = codec
                         break
+                else:
+                    codec = None
             if lines is None:
                 lines = list(self.hexdump(data, metrics))
             else:
@@ -181,9 +188,12 @@ class peek(HexViewer):
                 meta['ic']
             if index is not None:
                 meta['index'] = index
-            yield from self._peekmeta(metrics.hexdump_width, separator(), **meta)
+            for line in self._peekmeta(metrics.hexdump_width, separator(), **meta):
+                empty = False
+                yield line
 
         if lines:
+            empty = False
             if not self.args.brief:
                 yield separator(F'CODEC={codec}' if codec else None)
                 yield from lines
@@ -194,7 +204,7 @@ class peek(HexViewer):
                     brief = F'#{index:03d}: {brief}'
                 yield brief
 
-        if final:
+        if final and not empty:
             yield separator()
 
     def filter(self, chunks):
